#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-refactor-plugin
version:              2.3.0.0
visibility:           public
id:                   hls-refactor-plugin-2.3.0.0-G8XojnaKoxvI5XCS3WShcB
key:                  hls-refactor-plugin-2.3.0.0-G8XojnaKoxvI5XCS3WShcB
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           zubin.duggal@gmail.com
author:               The Haskell IDE Team
synopsis:             Exactprint refactorings for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  d41dc75af04bf53e87d60bdd2383853c
exposed:              True
exposed-modules:
    Development.IDE.GHC.Compat.ExactPrint Development.IDE.GHC.Dump
    Development.IDE.GHC.ExactPrint Development.IDE.Plugin.CodeAction
    Development.IDE.Plugin.CodeAction.Util

hidden-modules:
    Development.IDE.Plugin.CodeAction.Args
    Development.IDE.Plugin.CodeAction.ExactPrint
    Development.IDE.Plugin.CodeAction.PositionIndexed
    Development.IDE.Plugin.Plugins.AddArgument
    Development.IDE.Plugin.Plugins.Diagnostic
    Development.IDE.Plugin.Plugins.FillHole
    Development.IDE.Plugin.Plugins.FillTypeWildcard
    Development.IDE.Plugin.Plugins.ImportUtils

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-refactor-plugin-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-refactor-plugin-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-refactor-plugin-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-refactor-plugin
hs-libraries:         HShls-refactor-plugin-2.3.0.0-G8XojnaKoxvI5XCS3WShcB
depends:
    aeson-2.2.2.0-HX3VmpxSu7MBeXlY03a2B0 base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz deepseq-1.4.8.1
    dlist-1.0-B7D1vsARFiIHVaGk5CGbYO
    extra-1.7.16-9HJWsKGqeQNGNK4b68nPpp ghc-9.6.6 ghc-boot-9.6.6
    ghc-exactprint-1.7.1.0-8hKu1Ja81dnAmH9M3NOlwh
    ghcide-2.3.0.0-Bfg1eWqKv2P9EhjAubTTO0
    hls-graph-2.3.0.0-6ya4aMOTgUBOHsm6cIh9H
    hls-plugin-api-2.3.0.0-2cVMP2AJp9EB89sXuyaAt3
    lens-5.3.4-1IL9mxUdyyZ2Td3b3fp10G
    lsp-2.2.0.0-62EvDy2Nc6JD5v5vZC9bSk mtl-2.3.1
    parser-combinators-1.3.1-8aQ8dKOwDVmFxT1S1WvW6m
    regex-applicative-0.3.4-5GebqbEnaTt3sJBoAlPIkm
    regex-tdfa-1.3.2.5-H8j3gUuup0uJLVNboVGbR5
    retrie-1.2.3-1NOhFHzpfA8LoRTq9np4zt
    syb-0.7.3-IWvKvWWONKwAx7053zcTAl text-2.0.2
    text-rope-0.3-Et3zzhmV9C052PCXSjs9WW time-1.12.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-F8uKhGV3AlWbjcYkQjkcw

haddock-interfaces:
    /usr/share/doc/haskell-hls-refactor-plugin/html/hls-refactor-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-refactor-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

